@@ -16,7 +16,7 @@
 int save_part_as_pir(int debut, int fin, char **sequence, char **seqname, 
 	int *sel_seqs, int tot_seqs, char *fname, int *withU, int *num_longest, int protein);
 int replace_align_part(SEA_VIEW *view, int debut, int fin, char *fname, int withU, int num_longest,
-	int *tmpselseqs, align_choice mychoice);
+	int *tmpselseqs, align_choice mychoice, const char **err_message);
 void align_selected_parts(SEA_VIEW *view, int align_algorithm, align_choice my_align_choice);
 int calc_gap_sites(char *old_seq, char *new_seq, int lold, int lnew, 
 	gap_site *gap_sites, int maxsites);
@@ -90,7 +90,7 @@ for(num = 0; num < tot_seqs; num++) {
 	seqlen = 0;
 	for ( pos = debut - 1 ; pos < fin; pos++) {
 		if( sequence[num][pos] == 0 ) break;
-		if( sequence[num][pos] == '-' ) continue;
+		if( sequence[num][pos] == '-' || sequence[num][pos] == '!') continue;
 		if(empty_seq) {
 			sprintf(lname, "%d_%.10s", ++current, seqname[num]);
 			fprintf(out, ">%.10s\n", lname);
@@ -215,7 +215,7 @@ free(commande);
 sprintf(fname, "%s.out", base_fname);
 if( status == 0 ) {
 	in = fopen(fname, "r");
-	if(in != NULL) {
+        if(in != NULL) {
 		fseek(in, 0, SEEK_END);
 		status = (ftell(in) < 10);
 		fclose(in);
@@ -226,23 +226,20 @@ if (is_view_valid(view)) {
   if( status != 0 )
 	  fl_message("%s: alignment operation ignored", extract_filename(view->masename));
   else	{
-	  status = replace_align_part(view, debut, fin, fname, withU, num_longest, tmpselseqs, my_align_choice );
-	  if(status) fl_alert("Not enough memory\nor\n" 
-		  "max sequence length reached");
+	  const char *err_message;
+	  status = replace_align_part(view, debut, fin, fname, withU, num_longest, tmpselseqs, 
+				      my_align_choice, &err_message );
+	  if (status) fl_alert("%s", err_message);
 	  else if(my_align_choice == ALIGN_ALL) del_gap_only_sites(view);
 	  }
 }
 free(tmpselseqs);
-sprintf(fname, "%s.pir", base_fname);
-remove(fname);
-sprintf(fname, "%s.out", base_fname);
-remove(fname);
-sprintf(fname, "%s.dnd", base_fname);
-remove(fname);
-#ifndef WIN32
-sprintf(fname, "%s.status", base_fname);
-remove(fname);
+#ifdef WIN32
+  sprintf(fname, "DEL %s.*", base_fname);
+#else
+  sprintf(fname, "PATH=/bin:/usr/bin rm %s.*", base_fname);
 #endif
+system(fname);
 }
 
 
@@ -282,11 +279,12 @@ return tot_sites;
 
 
 int replace_align_part(SEA_VIEW *view, int debut, int fin, char *fname, 
-	int withU, int num_longest, int *tmpselseqs, align_choice mychoice)
+	int withU, int num_longest, int *tmpselseqs, align_choice mychoice,
+		       const char **err_message)
 /* returns TRUE if error, FALSE if ok */
 {
 int num, lfrag, lpart, i, rang, retval, newlength, lfrag2, total;
-char **seq, **comments, **seqname, *pheader, *err_message;
+char **seq, **comments, **seqname, *pheader;
 int (*calc_color_function)(int);
 int totgapsites, num1, site, l_copy, res;
 char *tmp;
@@ -296,12 +294,20 @@ for(num = 0; num < view->tot_seqs; num++) if(tmpselseqs[num]) total++;
 view->cursor_in_comment = FALSE;
 view->cursor_seq = view->first_seq;
 /* lecture de l'alignement multiple produit par clustalw */
-num = read_fasta_align(fname, &seq, &seqname, &comments, &pheader, &err_message, FALSE);
-if( reorder_seqs(num, seq, seqname) ) return TRUE;
+num = read_fasta_align(fname, &seq, &seqname, &comments, &pheader, (char **)err_message, FALSE);
+if(num == total && reorder_seqs(num, seq, seqname) ) {
+  *err_message = "Error: not enough memory.";
+  return TRUE;
+  }
 for(i = 0; i < num; i++) free(seqname[i]);
 if(num > 0) { free(seqname); free(comments); }
 if( num != total) {
 	if(num > 0) free(seq); 
+  static char *message = NULL;
+  if (message) free(message);
+  message = (char*)malloc(strlen(fname) + 100);
+  sprintf(message, "Error in file of aligned sequences:\n%s", fname);
+  *err_message = message;
 	return TRUE; 
 	}
 
@@ -316,7 +322,10 @@ if(withU) {
 	}	
 lfrag = strlen(seq[0]); /* long alignement de clustalw */
 lpart = fin - debut + 1; /*long region traitee de l'ancien alignement multiple*/
-if( reset_stars(view, debut, lpart, seq, lfrag, tmpselseqs) ) return TRUE;
+if( num = reset_stars(view, debut, lpart, seq, lfrag, tmpselseqs) ) {
+  *err_message = "Error: mismatch between alignment input and output.";
+  return TRUE;
+  }
 if(view->numb_gc > 1) {
 	calc_color_function = ( view->protein ? get_color_for_aa : get_color_for_base );
 	}
@@ -336,13 +345,18 @@ if(mychoice == ALIGN_SITES) {
 	totgapsites = calc_gap_sites(view->sequence[num_longest] + debut - 1, seq[num1],
 		FL_min(lpart, view->each_length[num_longest] - debut + 1),
 		lfrag, gap_sites, MAX_GAP_SITES);
-	if(totgapsites == -1) goto fin;
+	if(totgapsites == -1) {
+	  *err_message = "Error: reduce length of aligned sequences or increase parameter MAX_GAP_SITES.";
+	  goto fin;
+	  }
 	/* calcul long region traitee apres ajout des gaps */
 	for(site=0; site<totgapsites; site++) 
 		lpart += gap_sites[site].l[0];
 	/* l'alignement multiple serait-il trop long en fin d'operation? */
-	if( view->seq_length + lpart - (fin - debut + 1) > view->max_seq_length ) 
+	if( view->seq_length + lpart - (fin - debut + 1) > view->max_seq_length ) {
+	  *err_message = "Error: reduce length of aligned sequences.";
 		goto fin;
+	  }
 	/* calcul long alignement de clustalw apres ajout des gaps */
 	lfrag2 = lfrag;
 	for(site = 0; site < totgapsites; site++) 
@@ -350,7 +364,10 @@ if(mychoice == ALIGN_SITES) {
 	/* allongement memoire pour seqs de l'alignement de clustalw */
 	for(num=0; num<total; num++) {
 		tmp = (char *)malloc(lfrag2+1);
-		if(tmp == NULL) goto fin;
+		if(tmp == NULL) {
+		  *err_message = "Error: not enough memory.";
+		  goto fin;
+		  }
 		memcpy(tmp, seq[num], lfrag+1);
 		free(seq[num]);
 		seq[num] = tmp;
@@ -451,6 +468,8 @@ return lseqs + number;
 
 
 int reset_stars(SEA_VIEW *view, int debut, int lpart, char **seq, int lfrag, int *tmpselseqs)
+/* returns 0 iff OK, or mismatch between alignment input and output
+ */
 {
 int oldseq, newseq;
 char *p, *q;
@@ -463,16 +482,16 @@ for(oldseq = 0; oldseq < view->tot_seqs; oldseq++) {
 	q = seq[newseq] - 1;
 	while(TRUE) {
 		p++; q++;
-		while (*p == '-') p++;
-		while (*q == '-') q++;
+		while (*p == '-' || *p == '!') p++;
+		while (*q == '-' || *q == '!') q++;
 		if(*p == 0 || *q == 0) break;
 		if( *p == '*' && *q == 'X') *q = '*';
 		if( *p == '?' && *q == 'X') *q = '?';
-		if( toupper(*p) != toupper(*q) ) return TRUE;
+		if( toupper(*p) != toupper(*q) ) return 1;
 		if( islower(*p) ) *q = *p;
 		}
 	}
-return FALSE;
+return 0;
 }
 
 
@@ -1374,8 +1393,8 @@ int check_alignment_characters(SEA_VIEW *view, int *sel_seqs)
 {
   int i, choice;
   char *p, X;
-  const char dna_accepted[] = "ABCDGHKMNRSTUVWXY-*?";
-  const char prot_accepted[] = "ABCDEFGHIKLMNPQRSTVWXYZ-*?";
+  const char dna_accepted[] = "ABCDGHKMNRSTUVWXY-*?!";
+  const char prot_accepted[] = "ABCDEFGHIKLMNPQRSTVWXYZ-*?!";
   const char *accepted;
   char unexpected[50] = "", single[2] = "";
   
