@@ -2726,8 +2726,31 @@ else	{
 	}	
 }
 
+static void redresse_branches(raa_node *pere)
+/* Recursively reverse the order of descendants because it has been reversed
+ */
+{
+  struct raa_pair *point, *next1, *next2, *last;
+  point = pere->list_desc;
+  if (!point) return;
+  next1 = point->next;
+  if (next1) point->next = NULL;
+  while (TRUE) {
+    last = point;
+    redresse_branches(point->value);
+    if (!next1) break;
+    next2 = next1->next;
+    next1->next = point;
+    point = next1;
+    next1 = next2;
+    }
+  pere->list_desc = last;
+}
+
 
 static void ajout_branche(raa_node *pere, raa_node *fils)
+/* adds a pere->fils branch. The last added branch is the first child of pere.
+ */
 {
 struct raa_pair *point, *nouveau;
 
@@ -2737,8 +2760,8 @@ if( (point = pere->list_desc) == NULL) {
 	pere->list_desc = nouveau;
 	}
 else	{
-	while(point->next != NULL) point = point->next;
-	point->next = nouveau;
+  nouveau->next = pere->list_desc;
+  pere->list_desc = nouveau;
 	}
 }
 
@@ -2752,7 +2775,6 @@ synonyme est identifie par pere < 0 et -pere = son principal
 int num, pere, count, l;
 char *p, *q, *name, *libel;
 
-
 num = atoi(reponse);
 p = strchr(reponse, '&');
 pere = atoi(p + 1);
@@ -2897,6 +2919,7 @@ while(TRUE) {
 	}
 close_sock_gz_r(opaque);
 if(tab_noeud != NULL) {
+	redresse_branches(tab_noeud[2]);
 	raa_calc_taxo_count(tab_noeud[2]);
 	free(tab_noeud[2]->name);
 	tab_noeud[2]->name = strdup(rootname);
