@@ -805,7 +805,7 @@ while(TRUE) {
 		}
 	else if(strcmp(p, "CHARSET") == 0 && (limits = 
 		   process_sets_charset(in, &setname, max_chars)) != NULL) {
-		maregion = (region *)malloc(sizeof(region));
+		maregion = (region *)calloc(1, sizeof(region));
 		elt_reg = (list_regions *)malloc(sizeof(list_regions));
 		if(maregion != NULL && elt_reg != NULL) {
 			maregion->list = limits;
