@@ -366,7 +366,7 @@ for(l = nl; l > 0; l--) {
 void pdf_tree_plot(FD_nj_plot *fd_nj_plot)
 {
 	int t_font;
-	char *encoding;
+	const char *encoding;
 	FILE *f;
 	
 	double currx, curry;
