@@ -18,6 +18,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <signal.h>
+#include "FL/x.H"
 #include "FL/Fl.H"
 #include "FL/Fl_Window.H"
 #include "FL/Fl_Box.H"
@@ -330,20 +331,7 @@ int run_external_prog_in_pseudoterm(char *cmd, const char *dialogfname, const ch
   char *slavename;
 #if defined(__APPLE__) 
   char slavename2[50];
-  static SInt32 MACsystemVersion = 0;
-  if(!MACsystemVersion) Gestalt(gestaltSystemVersion, &MACsystemVersion);
-  if (MACsystemVersion < 0x1040) {
-  //before Mac OS X 10.4, use openpty instead of posix_openpt that does not exist
-    int slavefd;
-    if( openpty(&masterfd, &slavefd, slavename2, NULL, NULL) == -1) {
-      inuse = 0;
-      return 1; 
-      }
-    close(slavefd);
-    slavename = slavename2;
-    pid = fork();
-    }
-  else if (MACsystemVersion < 0x1050) { //special for Mac OS X 10.4 + i386
+  if (fl_mac_os_version < 100500) { //special for Mac OS X 10.4 + i386
     slavename = slavename2;
     pid = forkpty(&masterfd, slavename2, NULL, NULL);
     }
