@@ -14,7 +14,7 @@ region *duplicate_region(region *source, const char *name);
 void free_region(region *reg);
 region *copy_region(region *from, region *to);
 int create_full_region(SEA_VIEW *view, const char *name);
-void save_active_region(SEA_VIEW *view, int ask_confirm);
+void save_active_region(SEA_VIEW *view );
 void hide_region_line(SEA_VIEW *view);
 int create_codon_position_mask(SEA_VIEW *view, position_mask mask, const char *regname);
 int rename_current_region(SEA_VIEW *view, const char *name);
@@ -272,6 +272,7 @@ while(old != NULL) {
 l = strlen(name);
 p = (char *)calloc(l+1, 1);
 if(p == NULL) return TRUE; /*mess no mem serait mieux */;
+save_active_region(view);
 memcpy(p, name, l+1);
 free(view->active_region->name);
 view->active_region->name = p;
@@ -294,7 +295,7 @@ return TRUE;
 }
 
 
-void save_active_region(SEA_VIEW *view, int ask_confirm)
+void save_active_region(SEA_VIEW *view)
 { /* save changes in current region */
 list_regions *list;
 list_segments *act_seg, *mem_seg;
@@ -317,11 +318,10 @@ while ( (act_seg != NULL && mem_seg != NULL) ||
 	act_seg = act_seg->next;
 	mem_seg = mem_seg->next;
 	}
-if(ask_confirm) {
-	tmp = fl_choice("Do you want to save changes\nin current sites selection?\n%s", "Cancel", "Save", NULL, list->element->name);
-	}
-else	tmp = TRUE;
-if(tmp) list->element = copy_region(view->active_region, list->element);
+list->element = copy_region(view->active_region, list->element);
+if(view->format_for_save == MASE_FORMAT || view->format_for_save == NEXUS_FORMAT) {
+  set_seaview_modified(view, TRUE);
+  }
 }
 
 
@@ -565,15 +565,11 @@ void regions_menu_callback(Fl_Widget *ob, void *extra)
 	items[1].activate();
 	items[2].activate();
 	items[3].activate();
-	items[4].activate();
 	((Fl_Menu_ *)ob)->add(reg_name, 0, NULL, NULL, FL_MENU_RADIO);
 	taille++;
-	update_menu_taille_valeur(ob, taille, taille, 5);
+	update_menu_taille_valeur(ob, taille, taille, 4);
 	}
-  else if(reponse == 2) { /* save changes in current region */
-	  save_active_region(view, FALSE);
-	  }
-  else if(reponse == 3) { /* rename current region */
+  else if(reponse == 2) { /* duplicate current region */
 	  reg_name = fl_input("New set name?", view->active_region->name);
 	  if(reg_name == NULL) return;
 	  if( !rename_current_region(view, reg_name) ) {
@@ -583,19 +579,19 @@ void regions_menu_callback(Fl_Widget *ob, void *extra)
 	  view->DNA_obj->redraw();
 	  ((Fl_Menu_ *)ob)->add(reg_name, 0, NULL, NULL, FL_MENU_RADIO);
 	  taille++;
-	  update_menu_taille_valeur(ob, taille, taille, 5);
+	  update_menu_taille_valeur(ob, taille, taille, 4);
 	  }
-  else if(reponse == 4) { /* hide current region */
+  else if(reponse == 3) { /* hide current region */
+	  save_active_region(view);
 	  hide_region_line(view);
 	  view->DNA_obj->redraw();
 	  items[0].activate();
 	  items[1].deactivate();
 	  items[2].deactivate();
 	  items[3].deactivate();
-	  items[4].deactivate();
-	  update_menu_taille_valeur(ob, taille, 0, 5);
+	  update_menu_taille_valeur(ob, taille, 0, 4);
 	  }
-  else if(reponse == 5) { /* delete current region */
+  else if(reponse == 4) { /* delete current region */
 	  list_regions *list;
 	  int tmp;
 	  tmp = valeur;
@@ -608,22 +604,21 @@ void regions_menu_callback(Fl_Widget *ob, void *extra)
 		  items[1].deactivate();
 		  items[2].deactivate();
 		  items[3].deactivate();
-		  items[4].deactivate();
-		  ((Fl_Menu_ *)ob)->remove(valeur + 5 - 1);
-		  init_menu_taille_valeur(ob, taille - 1, 0, 5);
+		  ((Fl_Menu_ *)ob)->remove(valeur + 4 - 1);
+		  init_menu_taille_valeur(ob, taille - 1, 0, 4);
 		  }	
 	  }
   else	{ /* choix d'une region courante */
-	  valeur = reponse - 5;
+	  save_active_region(view);
+	  valeur = reponse - 4;
 	  activate_region_line(view, valeur);
 	  compute_size_params(view, TRUE);
 	  view->DNA_obj->redraw();
-	  update_menu_taille_valeur(ob, taille, valeur, 5);
+	  update_menu_taille_valeur(ob, taille, valeur, 4);
 	  items[0].deactivate();
 	  items[1].activate();
 	  items[2].activate();
 	  items[3].activate();
-	  items[4].activate();
 	  }
 }
 
