@@ -76,6 +76,7 @@ extern const char *make_binary_or_unrooted(char *arbre);
 extern int save_resources(void);
 extern int set_res_value(const char *name, const char *value);
 extern char *create_tmp_filename(void);
+extern int is_view_valid(SEA_VIEW *view);
 extern "C" {
 	char *dnapars(char** seq, char** seqname, int notu, int* steps, char* toevaluate, int arg_maxtrees, int *bt_weights);
 	char *protpars(char** seq, char** seqname, int notu, int* steps, char* toevaluate, int arg_maxtrees,
@@ -585,7 +586,7 @@ void phyml_dialog(SEA_VIEW *view)
 		mymodel->add("DCMut");
 		mymodel->add("VT");
 		mymodel->add("MtMam");
-		mymodel->add("MtART");
+		mymodel->add("MtArt");
 		mymodel->add("HIVw");
 		mymodel->add("HIVb");
 		mymodel->value(0);
@@ -764,6 +765,7 @@ void run_phyml_callback(Fl_Widget *ob, void *data)
   int replicates, cats, status, seqlen, user_tree = FALSE, i;
   float logL;
   char **tmpseqs, **tmpnames, **truenames;
+  int tot_seqs = view->tot_seqs;
   
   p = create_tmp_filename();
   if(p == NULL) return;
@@ -843,7 +845,7 @@ void run_phyml_callback(Fl_Widget *ob, void *data)
   sprintf(args, "%s -d %s -m %s -b %d -v %s -c %d -a %s",
 		  phyml_path, view->protein?"aa":"nt", modelname, replicates, invar, cats, alpha); 
   if( (!view->protein) && 
-  (strcmp(modelname,"K2P")==0 || strcmp(modelname,"HKY")==0 || strcmp(modelname,"F84")==0 || strcmp(modelname,"TN93")==0) ) {
+  (strcmp(modelname,"K80")==0 || strcmp(modelname,"HKY85")==0 || strcmp(modelname,"F84")==0 || strcmp(modelname,"TN93")==0) ) {
   if(r_estim->value()) {
 	  strcat(args, " -t e");
 	  }
@@ -908,7 +910,7 @@ void run_phyml_callback(Fl_Widget *ob, void *data)
   in = fopen(input, "r");
   if( status != 0 || in == NULL ) {
 	  if(in != NULL) fclose(in);
-	  fl_message("%s: tree building cancelled", extract_filename(view->masename));
+	  if (is_view_valid(view)) fl_message("%s: tree building cancelled", extract_filename(view->masename));
 	  }
   else {
 	  char *display_tree;
@@ -936,12 +938,12 @@ void run_phyml_callback(Fl_Widget *ob, void *data)
 	  char *tree = (char *)malloc(strlen(tree_label) + strlen(display_tree) + 4);
 	  sprintf(tree, "[%s] %s", tree_label, display_tree);
 	  free(display_tree);
-	  treedraw(tree, view, "PhyML_tree", FALSE);
+	  if (is_view_valid(view)) treedraw(tree, view, "PhyML_tree", FALSE);
 	  }
   remove(input);
   Fl::delete_widget(ob->window());
 way_out:
-  for(i = 0; i < view->tot_seqs; i++) {
+  for(i = 0; i < tot_seqs; i++) {
     if(truenames[i]) free(truenames[i]);
     }
   free(truenames);
