@@ -187,6 +187,7 @@ void squared2circular(FD_nj_plot *fd_nj_plot, Fl_Choice *o)
 	fd_nj_plot->swap_button->deactivate();
 	fd_nj_plot->subtree->deactivate();
 	fd_nj_plot->new_outgroup->deactivate();
+  fd_nj_plot->select->deactivate();
 	edit_item[4].deactivate();//edit header
 	edit_item[5].deactivate();//bootstrap threshold
 	edit_item[9].deactivate();//root at center
@@ -253,6 +254,7 @@ void circular2squared(FD_nj_plot *fd_nj_plot)
   fd_nj_plot->swap_button->activate();
   fd_nj_plot->subtree->activate();
   fd_nj_plot->new_outgroup->activate();
+  fd_nj_plot->select->activate();
   edit_item[4].activate();//edit header
   edit_item[5].activate();
   edit_item[9].activate();//root at center
@@ -549,9 +551,9 @@ void pdf_unrooted(FD_unrooted *fd_unrooted, const char *name)
 	FILE *f;
 	const int margin = 20;
 #ifdef WIN_MAC
-    char *encoding	= "macroman";
+    const char *encoding	= "macroman";
 #else
-    char *encoding	= "iso8859-1";
+    const char *encoding	= "iso8859-1";
 #endif
 	if(fd_unrooted->notu == 0) return;
 	Fl_Native_File_Chooser *chooser = new Fl_Native_File_Chooser();
@@ -690,7 +692,7 @@ double radius;
 if( (pname=preptree_unrooted(tree, fd_unrooted)) != NULL ) {
         char mess[150];
         strcpy(mess, pname);
-        fl_alert(mess);
+        fl_alert("%s", mess);
         fd_unrooted->notu = 0;
         return 1;
         }
