@@ -1532,9 +1532,10 @@ for(l = nl; l > 0; l--) {
 
 
 extern "C" { 
-	char *get_prog_dir(void); 
 #if defined(__APPLE__)
-	char *MG_GetBundleResourcesDir(void);
+	const char *MG_GetBundleResourcesDir(void);
+#else
+  char *get_prog_dir(void); 
 #endif
 	}
 
@@ -1563,7 +1564,7 @@ and then for it through all path directories
 returns NULL if not found 
 */
 {
-#define Mxdir 300
+#define Mxdir 600
 #ifdef WIN32
 #define PATH_SEPAR ';'
 #define DIR_SEPAR '\\'
