@@ -90,12 +90,10 @@ public:
 void my_watch_cursor(Fl_Window *win)
 {
 win->cursor(FL_CURSOR_WAIT); 
-Fl::flush();
 }
 
 void fl_reset_cursor(Fl_Window *win)
 {
-Fl::flush();
 win->cursor(FL_CURSOR_DEFAULT); 
 }
 
@@ -134,6 +132,8 @@ if(matpt->seq1 == NULL || seq1 != old_seq1 || seq2 != old_seq2) {
 	set_size_data(matpt);
 	old_seq1 = seq1; old_seq2 = seq2;
 	}
+  compute_region_text(matpt);
+  ((Fl_Slider*)(matpt->region_slider))->value(matpt->region_size);
 matpt->form->show();
 #ifndef MICRO
 	matpt->form->hotspot(matpt->form);
@@ -360,7 +360,6 @@ obj = new Fl_Slider(FL_HOR_FILL_SLIDER, fdui->region_box->x() + debut,
 obj->callback(region_size_proc, fdui);
 ((Fl_Slider *)obj)->when((Fl_When)(FL_WHEN_CHANGED | FL_WHEN_RELEASE));
 ((Fl_Slider *)obj)->bounds(4, maxbound);
-((Fl_Slider *)obj)->value(10);
 fdui->region_slider = obj;
 
 region_group->resizable(fdui->region_slider);
@@ -408,7 +407,7 @@ return fdui;
 
 static void err_message(const char *text)
 {
-fl_alert(text);
+fl_alert("%s", text);
 exit(1);
 }
 
@@ -643,7 +642,7 @@ label_draw_rect:
 	compute_region_text(matpt);
 	fl_reset_cursor(this->window());
 	if(erreur) {
-		fl_message(errmess);
+		fl_message("%s", errmess);
 		erreur = FALSE;
 		}
 }
@@ -660,14 +659,15 @@ if(event == FL_PUSH) {
 		return 1;
 	matpt->hitx = lx; matpt->hity = ly;
 	matpt->rect_only = TRUE;
-	matpt->mat_panel->redraw();
+  matpt->mat_panel->redraw();
+  compute_region_text(matpt);
 	Fl::focus(this);
 	return 1;
 	}
 else if(event == FL_KEYBOARD) {
 	int key = Fl::event_key();
 	if( key != FL_Right && key != FL_Left && 
-		key != FL_Up && key != FL_Down ) return 1;	
+		key != FL_Up && key != FL_Down ) return 0;	
 	if(key == FL_Left) {
 		matpt->hitx = FL_max(matpt->hitx - 5, 1);
 		matpt->hity = FL_max(matpt->hity - 5, 1);
@@ -684,6 +684,7 @@ else if(event == FL_KEYBOARD) {
 		}
 	matpt->rect_only = TRUE;
 	matpt->mat_panel->redraw();
+  compute_region_text(matpt);
 	return 1;
 	}
 else if(event == FL_FOCUS) {
@@ -764,6 +765,7 @@ my_watch_cursor(fdui->mat_panel->window());
 fdui->need_compute = TRUE;
 fdui->interrupted = FALSE;
 fdui->mat_panel->redraw();
+  fdui->region_box->redraw();
 if(!fdui->form->visible()) return;
 if(fdui->fenetre > fdui->region_size) fdui->region_size = fdui->fenetre;
 ((Fl_Slider *)fdui->region_slider)->value(fdui->region_size);
@@ -997,6 +999,7 @@ else	{
 	}
 matpt->rect_only = TRUE;
 matpt->mat_panel->redraw();
+  compute_region_text(matpt);
 }
 
 
@@ -1006,6 +1009,7 @@ FD_matpt *matpt = (FD_matpt *)data;
 matpt->region_size = (int)( ((Fl_Slider *)ob)->value() );
 matpt->rect_only = TRUE;
 matpt->mat_panel->redraw();
+  matpt->region_box->redraw();
 }
 
 
@@ -1153,6 +1157,7 @@ center_view_on_hit(matpt);
 matpt->mat_panel->redraw();
 matpt->x_slider->redraw();
 matpt->y_slider->redraw();
+  compute_region_text(matpt);
 compute_title(matpt);
 matpt->modif_but_not_saved = TRUE;
 }
